Enum fvm_shared::error::ExitCode
source · [−]#[repr(u32)]
pub enum ExitCode {
Show 24 variants
Ok,
SysErrSenderInvalid,
SysErrSenderStateInvalid,
SysErrInvalidMethod,
SysErrActorPanic,
SysErrInvalidReceiver,
SysErrInsufficientFunds,
SysErrOutOfGas,
SysErrForbidden,
SysErrIllegalActor,
SysErrIllegalArgument,
SysErrReserved2,
SysErrReserved3,
SysErrReserved4,
SysErrReserved5,
SysErrReserved6,
ErrIllegalArgument,
ErrNotFound,
ErrForbidden,
ErrInsufficientFunds,
ErrIllegalState,
ErrSerialization,
ErrTooManyProveCommits,
ErrPlaceholder,
}Expand description
ExitCode defines the exit code from the VM execution.
Variants
Ok
SysErrSenderInvalid
Indicates failure to find an actor in the state tree.
SysErrSenderStateInvalid
Indicates that the message sender was not in a valid state to send this message.
Either:
- The sender’s nonce nonce didn’t match the message nonce.
- The sender didn’t have the funds to cover the message gas.
SysErrInvalidMethod
Indicates failure to find a method in an actor.
SysErrActorPanic
Used for catching panics currently.
SysErrInvalidReceiver
Indicates that the receiver of a message is not valid (and cannot be implicitly created).
SysErrInsufficientFunds
Indicates a message sender has insufficient funds for a message’s execution.
SysErrOutOfGas
Indicates message execution (including subcalls) used more gas than the specified limit.
SysErrForbidden
Indicates a message execution is forbidden for the caller.
SysErrIllegalActor
Indicates actor code performed a disallowed operation. Disallowed operations include:
- mutating state outside of a state acquisition block
- failing to invoke caller validation
- aborting with a reserved exit code (including success or a system error).
SysErrIllegalArgument
Indicates an invalid argument passed to a runtime method.
SysErrReserved2
Reserved exit codes, do not use.
SysErrReserved3
SysErrReserved4
SysErrReserved5
SysErrReserved6
ErrIllegalArgument
Indicates a method parameter is invalid.
ErrNotFound
Indicates a requested resource does not exist.
ErrForbidden
Indicates an action is disallowed.
ErrInsufficientFunds
Indicates a balance of funds is insufficient.
ErrIllegalState
Indicates an actor’s internal state is invalid.
ErrSerialization
Indicates de/serialization failure within actor code.
ErrTooManyProveCommits
Power actor specific exit code.
ErrPlaceholder
Implementations
sourceimpl ExitCode
impl ExitCode
sourcepub fn is_success(self) -> bool
pub fn is_success(self) -> bool
Returns true if the exit code was a success
sourcepub fn is_system_error(self) -> bool
pub fn is_system_error(self) -> bool
Returns true if the error code is a system error.