pub struct StateRoot {
pub version: StateTreeVersion,
pub actors: Cid,
pub info: Cid,
}Expand description
State root information. Contains information about the version of the state tree, the root of the tree, and a link to the information about the tree.
Fields
version: StateTreeVersionState tree version
actors: CidActors tree. The structure depends on the state root version.
info: CidInfo. The structure depends on the state root version.