pub struct ZERO_ADDRESS { /* private fields */ }
Zero address used to avoid allowing it to be used for verification. This is intentionally disallowed because it is an edge case with Filecoin’s BLS signature verification.

Methods from Deref<Target = Address>

Returns protocol for Address

Returns the Payload object from the address, where the respective protocol data is kept in an enum separated by protocol

Returns the raw bytes data payload of the Address

Returns network configuration of Address

Get ID of the address. ID protocol only.